@@ -19,8 +19,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GUPNP_SERVICE_INFO_H__
-#define __GUPNP_SERVICE_INFO_H__
+#ifndef GUPNP_SERVICE_INFO_H
+#define GUPNP_SERVICE_INFO_H
 
 #include <glib-object.h>
 #include <libxml/tree.h>
@@ -31,45 +31,14 @@
 
 G_BEGIN_DECLS
 
-GType
-gupnp_service_info_get_type (void) G_GNUC_CONST;
-
 #define GUPNP_TYPE_SERVICE_INFO \
                 (gupnp_service_info_get_type ())
-#define GUPNP_SERVICE_INFO(obj) \
-                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-                 GUPNP_TYPE_SERVICE_INFO, \
-                 GUPnPServiceInfo))
-#define GUPNP_SERVICE_INFO_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_CAST ((obj), \
-                 GUPNP_TYPE_SERVICE_INFO, \
-                 GUPnPServiceInfoClass))
-#define GUPNP_IS_SERVICE_INFO(obj) \
-                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-                 GUPNP_TYPE_SERVICE_INFO))
-#define GUPNP_IS_SERVICE_INFO_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_TYPE ((obj), \
-                 GUPNP_TYPE_SERVICE_INFO))
-#define GUPNP_SERVICE_INFO_GET_CLASS(obj) \
-                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-                 GUPNP_TYPE_SERVICE_INFO, \
-                 GUPnPServiceInfoClass))
 
-typedef struct _GUPnPServiceInfoPrivate GUPnPServiceInfoPrivate;
-typedef struct _GUPnPServiceInfo GUPnPServiceInfo;
-typedef struct _GUPnPServiceInfoClass GUPnPServiceInfoClass;
-
-/**
- * GUPnPServiceInfo:
- *
- * This struct contains private data only, and should be accessed using the
- * functions below.
- */
-struct _GUPnPServiceInfo {
-        GObject parent;
-
-        GUPnPServiceInfoPrivate *priv;
-};
+G_DECLARE_DERIVABLE_TYPE (GUPnPServiceInfo,
+                          gupnp_service_info,
+                          GUPNP,
+                          SERVICE_INFO,
+                          GObject)
 
 struct _GUPnPServiceInfoClass {
         GObjectClass parent_class;
@@ -84,8 +53,8 @@ struct _GUPnPServiceInfoClass {
 /**
  * GUPnPServiceIntrospectionCallback:
  * @info: The #GUPnPServiceInfo introspection was requested for
- * @introspection: (nullable): The new #GUPnPServiceIntrospection object, or NULL
- * @error: (nullable): The #GError that occurred, or NULL
+ * @introspection: The new #GUPnPServiceIntrospection object, or NULL
+ * @error: The #GError that occurred, or NULL
  * @user_data: User data
  *
  * Callback notifying that @introspection for @info has been obtained.
@@ -123,10 +92,6 @@ gupnp_service_info_get_control_url            (GUPnPServiceInfo *info);
 char *
 gupnp_service_info_get_event_subscription_url (GUPnPServiceInfo *info);
 
-GUPnPServiceIntrospection *
-gupnp_service_info_get_introspection          (GUPnPServiceInfo *info,
-                                               GError          **error);
-
 void
 gupnp_service_info_get_introspection_async
                               (GUPnPServiceInfo                 *info,
@@ -142,4 +107,4 @@ gupnp_service_info_get_introspection_async_full
 
 G_END_DECLS
 
-#endif /* __GUPNP_SERVICE_INFO_H__ */
+#endif /* GUPNP_SERVICE_INFO_H */
